﻿using Hotline.FlowEngine.Definitions;
using Hotline.Share.Enums.FlowEngine;
using SqlSugar;

namespace Hotline.FlowEngine.Workflows;

/// <summary>
/// 流转记录
/// </summary>
public class WorkflowTrace : StepBasicEntity
{
    public string WorkflowId { get; set; }

    public string StepId { get; set; }

    /// <summary>
    /// 办理人部门code
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? OrgCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? OrgName { get; set; }

    /// <summary>
    /// 办理人
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? UserId { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? UserName { get; set; }

    /// <summary>
    /// 办理完成时间
    /// </summary>
    public DateTime? CompleteTime { get; set; }

    /// <summary>
    /// 接办人
    /// </summary>
    public string AcceptUserId { get; set; }

    public string AcceptUserName { get; set; }

    /// <summary>
    /// 接办时间
    /// </summary>
    public DateTime AcceptTime { get; set; }

    /// <summary>
    /// 流转记录状态
    /// </summary>
    public EWorkflowTraceStatus Status { get; set; }

    /// <summary>
    /// 过期时间
    /// </summary>
    public DateTime ExpiredTime { get; set; }

    #region 审批参数

    /// <summary>
    /// (下一节点办理人)根据审批者类型不同，此字段为不同内容
    /// <example>
    /// 部门等级/分类为：depCodes, 角色为：userIds
    /// </example>
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(2000)", IsJson = true)]
    public List<string> NextHandlers { get; set; }

    /// <summary>
    /// 下一节点主办，(NextHandlers其中一个, 如果不是会签则只有一个)
    /// </summary>
    public string NextMainHandler { get; set; }

    /// <summary>
    /// 下一节点code
    /// </summary>
    public string NextStepCode { get; set; }

    /// <summary>
    /// 是否短信通知
    /// </summary>
    public bool AcceptSms { get; set; }

    /// <summary>
    /// 办理意见
    /// </summary>
    [SugarColumn(Length = 2000)]
    public string Opinion { get; set; }

    /// <summary>
    /// 附件
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(1000)", IsJson = true)]
    public List<string> Additions { get; set; }

    #endregion

    /// <summary>
    /// 会签从属关系
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ParentId { get; set; }

    /// <summary>
    /// 会签流转记录
    /// </summary>
    [SugarColumn(IsIgnore = true)]
    public List<WorkflowTrace> Traces { get; set; }

    public void Previous(string userId, string userName, string orgCode, string orgName) =>
        Complete(userId, userName, orgCode, orgName, EWorkflowTraceStatus.Back);

    public void Recall(string userId, string userName, string orgCode, string orgName) =>
        Complete(userId, userName, orgCode, orgName, EWorkflowTraceStatus.Recall);

    public void Jump(string userId, string userName, string orgCode, string orgName) =>
        Complete(userId, userName, orgCode, orgName, EWorkflowTraceStatus.Jump);

    public void Complete(string userId, string userName, string orgCode, string orgName, EWorkflowTraceStatus status = EWorkflowTraceStatus.Normal)
    {
        OrgCode = orgCode;
        OrgName = orgName;
        UserId = userId;
        UserName = userName;
        CompleteTime = DateTime.Now;
        Status = status;
    }
}