﻿using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Orders;

/// <summary>
/// 工单扩展信息（12315-投诉）
/// </summary>
public class OrderComplain : FullStateEntity
{
    #region 投诉人信息

    /// <summary>
    /// 证件类型
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? LicenceTypeCode { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? LicenceType { get; set; }

    /// <summary>
    /// 证件号码, 证件类型已选的情况为必填，否则非必填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? LicenceNo { get; set; }

    /// <summary>
    /// 提供方类型（投诉人类型）
    /// </summary>
    public EProviderType? ProviderType { get; set; }

    /// <summary>
    /// 提供方身份（投诉人身份）
    /// </summary>
    public ECitizenStatus1? ProviderStatus { get; set; }

    /// <summary>
    /// 国籍或地区
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public ENationality? Nationality { get; set; }

    /// <summary>
    /// 民族
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? NationCode { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? Nation { get; set; }

    /// <summary>
    /// 邮政编码
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PostalCode { get; set; }

    /// <summary>
    /// 邮箱
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Email { get; set; }

    /// <summary>
    /// 其他联系方式
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? OtherContact { get; set; }

    #endregion

    #region 投诉对象信息

    /// <summary>
    /// 企业名称
    /// </summary>
    public string EnterpriseName { get; set; }

    /// <summary>
    /// 统一社会信用代码
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? UnifiedSocialCreditCode { get; set; }

    /// <summary>
    /// 注册地址
    /// </summary>
    public string RegisterAddress { get; set; }

    /// <summary>
    /// 注册号
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? RegisterNumber { get; set; }

    /// <summary>
    /// 企业联系人
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? EnterpriseContact { get; set; }

    /// <summary>
    /// 市场主体类型
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? MarketTypeCode { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? MarketType { get; set; }

    /// <summary>
    /// 行业分类
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? IndustryClassifyCode { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? IndustryClassify { get; set; }

    #endregion

    #region 投诉详情

    /// <summary>
    /// 商品品牌编码
    /// </summary>
    public string BrandCode { get; set; }

    /// <summary>
    /// 商品分类/品牌
    /// </summary>
    public string Brand { get; set; }

    /// <summary>
    /// 消费金额，只能填写数字，且只能填写非负数
    /// </summary>
    public decimal Amount { get; set; }

    /// <summary>
    /// 客体类别
    /// </summary>
    public string ObjectClassifyCode { get; set; }
    public string ObjectClassify { get; set; }

    /// <summary>
    /// 投诉问题类别
    /// </summary>
    public string ComplainClassifyCode { get; set; }
    public string ComplainClassify { get; set; }

    /// <summary>
    /// 争议发生时间
    /// </summary>
    public DateTime OccurrenceTime { get; set; }

    /// <summary>
    /// 销售方式
    /// </summary>
    public ESalesMode SalesMode { get; set; }

    /// <summary>
    /// 投诉目标，销售方式为“网购”时展示该字段且必填
    /// </summary>
    public EComplainTarget? ComplainTarget { get; set; }

    /// <summary>
    /// 电商平台，销售方式为“网购”时展示该字段且必填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ECommercePlatformCode { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? ECommercePlatform { get; set; }

    /// <summary>
    /// 外部订单号，销售方式为“ 网购”时展示该字段且必填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ExternalOrderNo { get; set; }

    /// <summary>
    /// 经营地址，销售方式为“现场”时必填
    /// </summary>
    //todo 地址信息不够完善
    [SugarColumn(IsNullable = true)]
    public string? BussinessArea { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? BussinessAddress { get; set; }

    /// <summary>
    /// 具体渠道
    /// <remarks>
    /// 销售方式为“电视购物”“电话购物”“邮购”时展示该字段，且必填
    /// 电视购物：请填写购物的电视频道
    /// 电话购物：请填写商品销售者的热线号码
    /// 邮购：请填写宣传商品的邮政公司或来件地址
    /// </remarks>
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Channel { get; set; }

    /// <summary>
    /// 专利权人，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Patentee { get; set; }

    /// <summary>
    /// 专利名称，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PatentName { get; set; }

    /// <summary>
    /// 专利类型，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    public EPatentType? PatentType { get; set; }

    /// <summary>
    /// 专利号，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PatentNo { get; set; }

    /// <summary>
    /// 产品名称
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ProductName { get; set; }

    /// <summary>
    /// 批准文号
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ApprovalNumber { get; set; }

    /// <summary>
    /// 产品批号
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ProductBatchNo { get; set; }

    /// <summary>
    /// 产品规格
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ProductStandard { get; set; }

    /// <summary>
    /// 产品有效期
    /// </summary>
    public DateTime ProductExpriedTime { get; set; }

    /// <summary>
    /// 生产厂家
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Manufacturer { get; set; }

    /// <summary>
    /// 销售企业
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? SalesEnterprise { get; set; }

    /// <summary>
    /// 消费者地址
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ConsumerAddress { get; set; }

    /// <summary>
    /// 诉求类型，多选
    /// </summary>
    public EComplainType? ComplainType { get; set; }

    #endregion
}

[Flags]
public enum EComplainType
{
    //修理、重做、更换、退货、补足商品数量、退赔费用、赔偿损失、停止侵权、核定侵权责任
}

public enum EPatentType
{
    //发明专利、实用新型专利、外观设计专利
}

public enum ENationality
{
    //中国、外国、港澳台地区
}

public enum ECitizenStatus1
{
    //城镇、农村、港澳台同胞、外籍、军人、学生、其他
}

public enum EProviderType
{
    //生产企业、销售企业、服务企业、其他企业、个体工商户、自然人、群诉、其他类型
}

public enum EComplainTarget
{
    //平台、入驻商家
}

public enum ESalesMode
{
    //网购、现场、电视购物、电话购物、邮购
}